@@ -1,9 +1,8 @@
-#!/usr/bin/env python
-# -*- coding: utf-8  -*-
+# -*- coding: utf-8 -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2012 Lance Edgar
+#  Copyright © 2010-2014 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -102,6 +101,8 @@ class ProductsGrid(SearchableAlchemyGridView):
             'subdepartment':
                 lambda q: q.outerjoin(Subdepartment,
                                       Subdepartment.uuid == Product.subdepartment_uuid),
+            u'report_code':
+                lambda q: q.outerjoin(model.ReportCode),
             'regular_price':
                 lambda q: q.outerjoin(ProductPrice,
                                       ProductPrice.uuid == Product.regular_price_uuid),
@@ -146,6 +147,7 @@ class ProductsGrid(SearchableAlchemyGridView):
             brand=self.filter_ilike(Brand.name),
             family=self.filter_ilike(model.Family.name),
             department=self.filter_ilike(Department.name),
+            report_code=self.filter_ilike(model.ReportCode.name),
             subdepartment=self.filter_ilike(Subdepartment.name),
             vendor=self.filter_ilike(Vendor.name),
             vendor_any=self.filter_ilike(self.VendorAny.name),
@@ -257,8 +259,9 @@ class ProductCrud(CrudView):
                 fs.description,
                 fs.size,
                 fs.department,
-                fs.family,
                 fs.subdepartment,
+                fs.family,
+                fs.report_code,
                 fs.regular_price,
                 fs.current_price,
                 ])
@@ -386,7 +389,7 @@ class CreateProductsBatch(ProductsGrid):
                         }
                     return render_to_response('/progress.mako', kwargs, request=self.request)
 
-        enabled = edbob.config.get('rattail.pyramid', 'batches.providers')
+        enabled = self.request.rattail_config.get('rattail.pyramid', 'batches.providers')
         if enabled:
             enabled = enabled.split()
 
